@@ -10,6 +10,7 @@ __PACKAGE__->load_components(qw/
   Serialize::Storable
   InflateColumn
   Relationship
+  PK::Auto
   PK
   Row
   ResultSourceProxy::Table
@@ -41,6 +42,8 @@ The core modules currently are:
 
 =item L<DBIx::Class::Relationship>
 
+=item L<DBIx::Class::PK::Auto>
+
 =item L<DBIx::Class::PK>
 
 =item L<DBIx::Class::Row>
