@@ -1,4 +1,5 @@
-package DBIx::Class::Relationship::HasOne;
+package # hide from PAUSE
+    DBIx::Class::Relationship::HasOne;
 
 use strict;
 use warnings;
@@ -13,18 +14,15 @@ sub has_one {
 
 sub _has_one {
   my ($class, $join_type, $rel, $f_class, $cond, $attrs) = @_;
-  eval "require $f_class";
-  if ($@) {
-    $class->throw_exception($@) unless $@ =~ /Can't locate/;
-  }
-
   unless (ref $cond) {
+    $class->ensure_class_loaded($f_class);
     my ($pri, $too_many) = $class->primary_columns;
-    $class->throw_exception( "might_have/has_one can only infer join for a single primary key; ${class} has more" )
-      if $too_many;
-    my $f_key;
+    $class->throw_exception(
+      "might_have/has_one can only infer join for a single primary key; ".
+      "${class} has more"
+    ) if $too_many;
     my $f_class_loaded = eval { $f_class->columns };
-    my $guess;
+    my ($f_key,$guess);
     if (defined $cond && length $cond) {
       $f_key = $cond;
       $guess = "caller specified foreign key '$f_key'";
@@ -33,12 +31,15 @@ sub _has_one {
       $guess = "using given relationship '$rel' for foreign key";
     } else {
       ($f_key, $too_many) = $f_class->primary_columns;
-      $class->throw_exception( "might_have/has_one can only infer join for a single primary key; ${f_class} has more" )
-        if $too_many;
+      $class->throw_exception(
+        "might_have/has_one can only infer join for a single primary key; ".
+        "${f_class} has more"
+      ) if $too_many;
       $guess = "using primary key of foreign class for foreign key";
     }
-    $class->throw_exception("No such column ${f_key} on foreign class ${f_class} ($guess)")
-      if $f_class_loaded && !$f_class->has_column($f_key);
+    $class->throw_exception(
+      "No such column ${f_key} on foreign class ${f_class} ($guess)"
+    ) if $f_class_loaded && !$f_class->has_column($f_key);
     $cond = { "foreign.${f_key}" => "self.${pri}" };
   }
   $class->add_relationship($rel, $f_class,
